;;;; Example lisp code.
(in-package :asdf-test)

(defun tst (x)
  (1+ x))

(defun add10 (x)
  (+ x 10))
